@@ -32,11 +32,11 @@
 #include "gnome-vfs-result.h"
 #include "gnome-vfs-private-utils.h"
 #include "gnome-vfs-utils.h"
-#include "gnome-vfs-i18n.h"
 #include <bonobo-activation/bonobo-activation-activate.h>
 #include <gconf/gconf-client.h>
 #include <stdio.h>
 #include <string.h>
+#include <glib/gi18n-lib.h>
 
 #define GCONF_DEFAULT_VIEWER_EXEC_PATH   "/desktop/gnome/applications/component_viewer/exec"
 
@@ -81,6 +81,11 @@ static GList *        copy_str_list                              (GList
 const char *
 gnome_vfs_mime_get_description (const char *mime_type)
 {
+	/* We use a different folder type than the freedesktop spec */
+	if (strcmp (mime_type, "x-directory/normal") == 0) {
+		mime_type = "inode/directory";
+	}
+		
 	return gnome_vfs_mime_get_value (mime_type, "description");
 }
 
